==> inline-neoforge-1.21.1-1.0.3-59-sources.jar: com/samsthenerd/inline/api/client/renderers/InlineSpriteRenderer.java <==
package com.samsthenerd.inline.api.client.renderers;

import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.vertex.PoseStack;
import com.samsthenerd.inline.Inline;
import com.samsthenerd.inline.api.client.GlowHandling;
import com.samsthenerd.inline.api.client.InlineRenderer;
import com.samsthenerd.inline.api.data.SpriteInlineData;
import com.samsthenerd.inline.utils.SpritelikeRenderers;
import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.network.chat.Style;
import net.minecraft.resources.ResourceLocation;

public class InlineSpriteRenderer implements InlineRenderer<SpriteInlineData>{

    public static final InlineSpriteRenderer INSTANCE = new InlineSpriteRenderer();

    public ResourceLocation getId(){
        return Inline.id( "spritelike");
    
    }

    public int render(SpriteInlineData data, GuiGraphics context, int index, Style style, int codepoint, TextRenderingContext trContext){
        if(data == null || data.sprite == null) return 0;
        float height = data.sprite.getSpriteHeight();
        if(height == 0){
            return 0;
        }
        float width = data.sprite.getSpriteWidth();
        float whRatio = (width / (float)height);
        PoseStack matrices = context.pose();
        matrices.translate(0, 0, 1);
        RenderSystem.enableDepthTest();
        SpritelikeRenderers.getRenderer(data.sprite).drawSpriteWithLight(data.sprite, context, 0, 0, 0, 8 * width / height,8, trContext.light(), 0xFFFFFFFF);
        return (int)Math.ceil(whRatio * 8);
    }

    public int charWidth(SpriteInlineData data, Style style, int codepoint){
        if(data == null || data.sprite == null) return 0;
        int height = data.sprite.getSpriteHeight();
        if(height == 0){
            return 0;
        }
        return (int)Math.ceil(8.0 * data.sprite.getSpriteWidth() / (float)height);
    }

    // spritelikes aren't really built to handle animated sprites so it's fine.
    @Override
    public GlowHandling getGlowPreference(SpriteInlineData forData){
        return new GlowHandling.Full(forData.sprite.getTextureId().toLanguageKey() + Integer.toHexString(forData.sprite.hashCode()).toLowerCase());
    }
}

==> inline-neoforge-1.21.1-1.2.1-71-sources.jar: com/samsthenerd/inline/api/client/renderers/InlineSpriteRenderer.java <==
package com.samsthenerd.inline.api.client.renderers;

import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.vertex.PoseStack;
import com.samsthenerd.inline.Inline;
import com.samsthenerd.inline.api.client.GlowHandling;
import com.samsthenerd.inline.api.client.InlineRenderer;
import com.samsthenerd.inline.api.data.SpriteInlineData;
import com.samsthenerd.inline.utils.SpriteUVRegion;
import com.samsthenerd.inline.utils.SpritelikeRenderers;
import java.util.Objects;
import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.network.chat.Style;
import net.minecraft.resources.ResourceLocation;

public class InlineSpriteRenderer implements InlineRenderer<SpriteInlineData>{

    public static final InlineSpriteRenderer INSTANCE = new InlineSpriteRenderer();

    public ResourceLocation getId(){
        return Inline.id( "spritelike");
    
    }

    public int render(SpriteInlineData data, GuiGraphics context, int index, Style style, int codepoint, TextRenderingContext trContext){
        if(data == null || data.sprite == null) return 0;
        SpriteUVRegion uvs = data.sprite.getUVs();
        double height = uvs.vHeight() * data.sprite.getTextureHeight();
        if(height == 0){
            return 0;
        }
        double width = uvs.uWidth() * data.sprite.getTextureWidth();
        float whRatio = (float) (width / height);
        PoseStack matrices = context.pose();
        matrices.translate(0, 0, 1);
        RenderSystem.enableDepthTest();
        SpritelikeRenderers.getRenderer(data.sprite).drawSpriteWithLight(data.sprite, context, 0, 0, 0, 8 * whRatio,8, trContext.light(),
            data.shouldTint ? trContext.usableColor() : 0xFFFFFFFF);
        return (int)Math.ceil(whRatio * 8);
    }

    public int charWidth(SpriteInlineData data, Style style, int codepoint){
        if(data == null || data.sprite == null) return 0;
        SpriteUVRegion uvs = data.sprite.getUVs();
        double height = uvs.vHeight() * data.sprite.getTextureHeight();
        if(height == 0){
            return 0;
        }
        double width = uvs.uWidth() * data.sprite.getTextureWidth();
        float whRatio = (float) (width / height);
        return (int)Math.ceil(8.0 * whRatio);
    }

    // spritelikes aren't really built to handle animated sprites so it's fine.
    @Override
    public GlowHandling getGlowPreference(SpriteInlineData forData){
        return new GlowHandling.Full(Objects.requireNonNullElse(forData.sprite.getTextureId(), ResourceLocation.parse("")).toLanguageKey() + Integer.toHexString(forData.sprite.hashCode()).toLowerCase());
    }
}
